@@ -354,7 +354,7 @@ class ChannelDB(SqlDB):
     def get_200_randomly_sorted_nodes_not_in(self, node_ids):
         with self.lock:
             unshuffled = set(self._nodes.keys()) - node_ids
-        return random.sample(unshuffled, min(200, len(unshuffled)))
+        return random.sample(list(unshuffled), min(200, len(unshuffled)))
 
     def get_last_good_address(self, node_id: bytes) -> Optional[LNPeerAddr]:
         """Returns latest address we successfully connected to, for given node."""
@@ -826,7 +826,7 @@ class ChannelDB(SqlDB):
             *,
             my_channels: Dict[ShortChannelID, 'Channel'] = None,
             private_route_edges: Dict[ShortChannelID, 'RouteEdge'] = None,
-    ) -> Set[bytes]:
+    ) -> Set[ShortChannelID]:
         """Returns the set of short channel IDs where node_id is one of the channel participants."""
         if not self.data_loaded.is_set():
             raise Exception("channelDB data not loaded yet!")
