@@ -498,6 +498,9 @@ def standardize_path(path):
 
 
 def get_new_wallet_name(wallet_folder: str) -> str:
+    """Returns a file basename for a new wallet to be used.
+    Can raise OSError.
+    """
     i = 1
     while True:
         filename = "wallet_%d" % i
@@ -1467,11 +1470,24 @@ def is_ip_address(x: Union[str, bytes]) -> bool:
         return False
 
 
-def is_private_netaddress(host: str) -> bool:
+def is_localhost(host: str) -> bool:
     if str(host) in ('localhost', 'localhost.',):
         return True
     if host[0] == '[' and host[-1] == ']':  # IPv6
         host = host[1:-1]
+    try:
+        ip_addr = ipaddress.ip_address(host)  # type: Union[IPv4Address, IPv6Address]
+        return ip_addr.is_loopback
+    except ValueError:
+        pass  # not an IP
+    return False
+
+
+def is_private_netaddress(host: str) -> bool:
+    if is_localhost(host):
+        return True
+    if host[0] == '[' and host[-1] == ']':  # IPv6
+        host = host[1:-1]
     try:
         ip_addr = ipaddress.ip_address(host)  # type: Union[IPv4Address, IPv6Address]
         return ip_addr.is_private
